@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2016 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2018 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -16,6 +16,7 @@ $Data{'currency'}{'iso'}{'orig'}{'name'} = {
    "Unidades de fomento "  => "Unidades de fomento",
    "Pa’anga"               => "Pa'anga",
    "Pa\x{2019}anga"        => "Pa'anga",
+   " P a  a n g a"   => "Pa'anga",
    "US Dollar (Next day) " => "US Dollar (Next day)",
    "US Dollar (Same day) " => "US Dollar (Same day)",
    "Bond Markets Unit European Monetary Unit (E.M.U.-6) "
@@ -33,6 +34,7 @@ $Data{'currency'}{'iso'}{'orig'}{'name'} = {
    "SAINT BARTH?LEMY"   => "Saint Barthelemy",
    "Bolívar"            => "Bolivar",
    "Bol\x{ed}var"       => "Bolivar",
+   "Bolvar Soberano"   => "Bolivar Soberano",
 };
 
 $Data{'currency'}{'iso'}{'ignore'} = {
